==> react-container-file-uploader-0.1.302.tgz: package/es/index.js <==
import _extends from 'babel-runtime/helpers/extends';

var _desc, _value, _class;

function _applyDecoratedDescriptor(target, property, decorators, descriptor, context) {
  var desc = {};
  Object['ke' + 'ys'](descriptor).forEach(function (key) {
    desc[key] = descriptor[key];
  });
  desc.enumerable = !!desc.enumerable;
  desc.configurable = !!desc.configurable;

  if ('value' in desc || desc.initializer) {
    desc.writable = true;
  }

  desc = decorators.slice().reverse().reduce(function (desc, decorator) {
    return decorator(target, property, desc) || desc;
  }, desc);

  if (context && desc.initializer !== void 0) {
    desc.value = desc.initializer ? desc.initializer.call(context) : void 0;
    desc.initializer = undefined;
  }

  if (desc.initializer === void 0) {
    Object['define' + 'Property'](target, property, desc);
    desc = null;
  }

  return desc;
}

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import { bindActionCreators } from 'redux';
import classNames from 'classnames';
import { autobind } from 'core-decorators';
import { constructFiles } from '@ciscospark/react-component-utils';
import { addFiles, removeFile } from '@ciscospark/redux-module-activity';
import AddFileButton from '@ciscospark/react-component-add-file-button';
import FileStagingArea from '@ciscospark/react-component-file-staging-area';

var styles = {
  'buttonContainer': 'buttonContainer--3MeCz'
}; // @related-file ./styles.css

const injectedPropTypes = {
  activity: PropTypes.object.isRequired,
  conversation: PropTypes.object.isRequired,
  spark: PropTypes.object.isRequired,
  addFiles: PropTypes.func.isRequired,
  removeFile: PropTypes.func.isRequired
};

const propTypes = _extends({
  onSubmit: PropTypes.func.isRequired
}, injectedPropTypes);

export let FileUploader = (_class = class FileUploader extends Component {
  shouldComponentUpdate(nextProps) {
    const { props } = this;
    return nextProps.activity !== props.activity;
  }

  handleFileChange(e) {
    e.stopPropagation();
    e.preventDefault();

    if (e.target.files.length) {
      const { props } = this;
      const {
        activity,
        conversation,
        spark
      } = props;

      const files = constructFiles(e.target.files);
      props.addFiles(conversation, activity, files, spark);

      // Clear the value of the input so the same file can be added again.
      e.target.value = '';
    }
  }

  handleFileRemove(id) {
    const { props } = this;
    props.removeFile(id, props.activity);
  }

  render() {
    const {
      onSubmit,
      activity
    } = this.props;
    const files = activity.get('files');

    let stagingArea;
    if (files && files.count()) {
      stagingArea = React.createElement(FileStagingArea, {
        files: files,
        onFileRemove: this.handleFileRemove,
        onSubmit: onSubmit
      });
    }

    return React.createElement(
      'div',
      { className: classNames('ciscospark-file-uploader-container', styles.container) },
      stagingArea,
      React.createElement(
        'div',
        { className: classNames('ciscospark-button-container', styles.buttonContainer) },
        React.createElement(AddFileButton, { onChange: this.handleFileChange })
      )
    );
  }
}, (_applyDecoratedDescriptor(_class.prototype, 'handleFileChange', [autobind], Object.getOwnPropertyDescriptor(_class.prototype, 'handleFileChange'), _class.prototype), _applyDecoratedDescriptor(_class.prototype, 'handleFileRemove', [autobind], Object.getOwnPropertyDescriptor(_class.prototype, 'handleFileRemove'), _class.prototype)), _class);

FileUploader.propTypes = propTypes;

export default connect(state => ({
  activity: state.activity,
  conversation: state.conversation,
  spark: state.spark.get('spark')
}), dispatch => bindActionCreators({
  addFiles,
  removeFile
}, dispatch))(FileUploader);

==> react-container-file-uploader-0.1.334.tgz: package/es/index.js <==
import _extends from 'babel-runtime/helpers/extends';

var _desc, _value, _class;

function _applyDecoratedDescriptor(target, property, decorators, descriptor, context) {
  var desc = {};
  Object['ke' + 'ys'](descriptor).forEach(function (key) {
    desc[key] = descriptor[key];
  });
  desc.enumerable = !!desc.enumerable;
  desc.configurable = !!desc.configurable;

  if ('value' in desc || desc.initializer) {
    desc.writable = true;
  }

  desc = decorators.slice().reverse().reduce(function (desc, decorator) {
    return decorator(target, property, desc) || desc;
  }, desc);

  if (context && desc.initializer !== void 0) {
    desc.value = desc.initializer ? desc.initializer.call(context) : void 0;
    desc.initializer = undefined;
  }

  if (desc.initializer === void 0) {
    Object['define' + 'Property'](target, property, desc);
    desc = null;
  }

  return desc;
}

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import { bindActionCreators } from 'redux';
import classNames from 'classnames';
import { autobind } from 'core-decorators';
import { constructFiles } from '@ciscospark/react-component-utils';
import { addFiles, removeFile } from '@ciscospark/redux-module-activity';
import AddFileButton from '@ciscospark/react-component-add-file-button';
import FileStagingArea from '@ciscospark/react-component-file-staging-area';

import getContainerProps from './selectors';

var styles = {
  'buttonContainer': 'buttonContainer--3MeCz'
}; // @related-file ./styles.css

const injectedPropTypes = {
  activity: PropTypes.object.isRequired,
  conversation: PropTypes.object.isRequired,
  spark: PropTypes.object.isRequired,
  addFiles: PropTypes.func.isRequired,
  removeFile: PropTypes.func.isRequired
};

const propTypes = _extends({
  onSubmit: PropTypes.func.isRequired
}, injectedPropTypes);

export let FileUploader = (_class = class FileUploader extends Component {
  shouldComponentUpdate(nextProps) {
    const { props } = this;
    return nextProps.activity !== props.activity;
  }

  handleFileChange(e) {
    e.stopPropagation();
    e.preventDefault();

    if (e.target.files.length) {
      const { props } = this;
      const {
        activity,
        conversation,
        spark
      } = props;

      const files = constructFiles(e.target.files);
      props.addFiles(conversation, activity, files, spark);

      // Clear the value of the input so the same file can be added again.
      e.target.value = '';
    }
  }

  handleFileRemove(id) {
    const { props } = this;
    props.removeFile(id, props.activity);
  }

  render() {
    const {
      onSubmit,
      activity
    } = this.props;
    const files = activity.get('files');

    let stagingArea;
    if (files && files.count()) {
      stagingArea = React.createElement(FileStagingArea, {
        files: files,
        onFileRemove: this.handleFileRemove,
        onSubmit: onSubmit
      });
    }

    return React.createElement(
      'div',
      { className: classNames('ciscospark-file-uploader-container', styles.container) },
      stagingArea,
      React.createElement(
        'div',
        { className: classNames('ciscospark-button-container', styles.buttonContainer) },
        React.createElement(AddFileButton, { onChange: this.handleFileChange })
      )
    );
  }
}, (_applyDecoratedDescriptor(_class.prototype, 'handleFileChange', [autobind], Object.getOwnPropertyDescriptor(_class.prototype, 'handleFileChange'), _class.prototype), _applyDecoratedDescriptor(_class.prototype, 'handleFileRemove', [autobind], Object.getOwnPropertyDescriptor(_class.prototype, 'handleFileRemove'), _class.prototype)), _class);

FileUploader.propTypes = propTypes;

export default connect(getContainerProps, dispatch => bindActionCreators({
  addFiles,
  removeFile
}, dispatch))(FileUploader);
